#region Directives
using System.Web.Services;
using System.Web.Services.Protocols;
using BunnyEventListener.Services;
using Nabaztag;
#endregion

/// <summary>
/// Web Service Endpoint for the <see cref="CheckinEvent"/>
/// </summary>
/// <remarks>
/// To Register this Notification Endpoint you will need to use the <see cref="http://blogs.msdn.com/psheill/archive/2006/02/01/522386.aspx">BisSubscribe.exe</see> tool. 
/// For more information about Team Foundation Server Notifications <see cref="http://blogs.msdn.com/buckh/archive/2006/04/10/event_filtering.aspx"/>
/// </remarks>
[WebService(Namespace = "http://schemas.woodwardweb.com/TeamFoundation/2005/06/Services/Notification/Extensibility", Description = "")]
[WebServiceBinding(ConformsTo = WsiProfiles.BasicProfile1_1)]
public class CheckInEndpoint : EndpointBase
{
    /// <summary>
    /// Endpoint required to accept incoming <see cref="CheckinEvent"/> notifications
    /// </summary>
    /// <param name="eventXml">Serialized version of the <see cref="CheckinEvent"/></param>
    /// <param name="tfsIdentityXml">Serialized version of <see cref="TFSIdentity"/></param>
    [WebMethod]
    [SoapDocumentMethod("http://schemas.microsoft.com/TeamFoundation/2005/06/Services/Notification/03/Notify", RequestNamespace = "http://schemas.microsoft.com/TeamFoundation/2005/06/Services/Notification/03")]
    public void Notify(string eventXml, string tfsIdentityXml)
    {
        CheckinEvent checkInEvent = this.CreateInstance<CheckinEvent>(eventXml);
        TFSIdentity tfsIdentity = this.CreateInstance<TFSIdentity>(tfsIdentityXml);

        string message;
        if(string.IsNullOrEmpty(checkInEvent.Comment))
        {
            message = string.Format("{0} just checked in..",UserNameUtil.GetUserName(checkInEvent.Committer));
        }
        else
        {
            message = string.Format("{0} just checked in with the comment, \"{1}\"..",UserNameUtil.GetUserName(checkInEvent.Committer), checkInEvent.Comment);        
        }

        Bunny bunny = new Bunny(BunnyConstants.SerialNumber, BunnyConstants.ApiToken);
        bunny.SendMessage(message);

    }
}
